<?lsp

local fmt=string.format
local io=app.docsIo

-- if via cfgalbum.lsp
local albumMode = not response:initial() and true or false

-- remove trailing and leading whitespace from string, returns the string or the default.
local function optString(s,def)
   if s then
      s= s:gsub("^%s*(.-)%s*$", "%1")
      if #s > 0 then return s end
   end
   return def
end

local function getAlbumName()
   local n = 1
   while true do
      local name = fmt("Album-%d",n)
      if not io:stat(name) then
         return name
      end
      n=n+1
   end
end

local function getCfg(cms)
   local cfg = cms.imgUplCfg
   -- Config data used by imageupload.lua
   if not cfg then
      cfg = {}
      cms.imgUplCfg=cfg
      cms.imgUplService=nil -- Must make imageupload.lua create a new I/O
   end
   cfg.quality=cfg.quality or 80
   cfg.stats = cfg.stats or {files=0,images=0}
   if albumMode then
      cfg.w = cfg.w and cfg.w or 800
      cfg.h = cfg.h and cfg.h or 600
      cfg.thumbw = cfg.thumbw and cfg.thumbw or 120
      cfg.thumbh = cfg.thumbh and cfg.thumbh or 120
      cfg.albumtitle=optString(cfg.albumtitle, getAlbumName())
   else
      cfg.w = cfg.w and cfg.w or 480
      cfg.h = cfg.h and cfg.h or 480
      cfg.thumbw = nil
      cfg.thumbh = nil
   end
   return cfg
end
local s=request:session()
local cms = app.getCmsTab(s)
local cfg = getCfg(cms)

local function initUpload(cfg)
   local env,conn = app.openDb()
   local imgNames={}
   cfg.imgNames =imgNames
   local q=fmt(
    [[SELECT PhotoAlbums.img FROM
      PhotoAlbumNames,PhotoAlbums
      WHERE PhotoAlbumNames.name="%s" AND
      PhotoAlbumNames.key = PhotoAlbums.album
     ORDER BY PhotoAlbums.key]], cfg.albumtitle)
   local cur=conn:execute(q)
   if cur then
      local img = cur:fetch()
      while img do
         imgNames[img]=true
         img = cur:fetch()
      end
      cur:close()
   end
   app.closeDb(env,conn)
end


if request:method() == "POST" then
   local d = request:data()
   d.inline=nil
   if d.doneUplUrl then
      cms.doneUplUrl=d.doneUplUrl
      cms.cancelUplUrl=d.doneUplUrl
   else
      local n
      local albumtitle=optString(d.albumtitle, albumMode and getAlbumName() or "images")
      albumtitle = albumtitle:gsub("%s+", "-"):gsub("[^%w]+",
                     function(d) if d == "-" then return d end return "" end)
      d.albumtitle=nil
      for k,v in pairs(d) do
         n=tonumber(v)
         if not n or n < 1 then n=nil break end
         cfg[k]=n
      end
      cfg.albumtitle=albumtitle
      if n then
         if not io:stat(cfg.albumtitle) then io:mkdir(cfg.albumtitle) end
         cfg.quality = cfg.quality > 100 and 100 or cfg.quality
         initUpload(cfg)
         app.imageUploadMgr(s)
         response:sendredirect"upload.lsp"
         return
      end
   end
end
if not cms.doneUplUrl then
   cms.doneUplUrl = albumMode and "managealbum.lsp" or request:uri()
end
local ltitle=fmt("%s Uploader", albumMode and "Photo Album" or "Image")
local inlineMode=request:data"inline" == "true"
if inlineMode then -- Used by the wiziwyg editor
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
<title>Configure <?lsp=ltitle?></title>
<link href="../style.css" rel="stylesheet" type="text/css" />
<link href="../help.css" rel="stylesheet" type="text/css" />
<script type="text/javascript" src="/rtl/jquery.js"></script>
<script type="text/javascript" src="../help.js"></script>
</head>
<body>
<?lsp
else
title="CMS: Manage Images: "..ltitle
response:include"../.header.lsp"
end
?>
<script type="text/javascript">
$(function(){
   initHelp("images","../");
   function selalb() {
      var an = $(this).val();
      $("#albumname").attr("value",an);
      $("#appendinfo").html('Append to album "'+an+'"');
   }
   $("select").change(selalb).click(selalb);
   function erase(){ $("#appendinfo").html(""); }
   $("#albumname").change(erase).keypress(erase);
   $("#cancelbut").click(function() {
      if(parent != window && parent.doneUploading)
         parent.doneUploading(false);
      else
         window.location='<?lsp=cms.cancelUplUrl and cms.cancelUplUrl or "../images.lsp" ?>';
      return false
   });
});
</script>
<div id="help"></div>
<h1 style="text-align:center">Configure <?lsp=ltitle?></h1>
<img hlp='<?lsp= albumMode and "album" or "upload"?>' src='../btn/questionmark.32.gif' alt='Help' style='float:right;margin:0 8em 0 0;border:none'/>
<br/>
<div class="manage" style="width:500px">
<?lsp if albumMode then ?>
<fieldset><legend>Album</legend>
<form method="post">
<table>
<?lsp
local alist = app.io:loadfile(pathname:match("(.-)[^/]+$")..".albumlist.lua")(app)
if #alist > 0 then
   print'<tr><td>Existing&nbsp;Albums:</td><td><select>'
   for _,name in ipairs(alist) do
      response:write("<option>",name,"</option>")
   end
   print'</select></td></tr>'
end
?>
<tr>
  <td>Album&nbsp;Name:</td>
  <td><input id="albumname" type="text" style="width:250px" name="albumtitle" value="<?lsp=cfg.albumtitle?>" /><div id="appendinfo" style="color:blue"></div></td>
</tr>
</table>
</fieldset>
<br/>
<?lsp end ?>
<fieldset><legend>JPEG Image Size</legend>
<form method="post">
<table>
<tr>
  <td>Max Image Width:</td>
  <td><input type="text" name="w" value="<?lsp=cfg.w?>" /></td>
</tr>
<tr>
  <td>Max Image Height:</td>
  <td><input type="text" name="h" value="<?lsp=cfg.h?>" /></td>
</tr>
<tr>
  <td>Image Quality %:</td>
  <td><input type="text" name="quality" value="<?lsp=cfg.quality?>" /></td>
</tr>
</table>
</fieldset>
<br/>
<?lsp if albumMode then ?>
<fieldset>
    <legend>Thumb Size</legend>
    <table>
      <tr>
        <td>Max Image Width:</td>
        <td><input type="text" name="thumbw" value="<?lsp=cfg.thumbw?>" /></td>
      </tr>
      <tr>
        <td>Max Image Height:</td>
        <td><input type="text" name="thumbh" value="<?lsp=cfg.thumbh?>" /></td>
     </tr>
</table>
</fieldset>
<br/>
<?lsp end ?>

<input id="cancelbut" style="float:right" type="submit" value="Cancel Upload"/>
<input type="submit" value="Start Web File Manager" />
</form>
</div>
<?lsp 

if inlineMode then
   response:write'</body></html>'
else
   response:include"../.footer.lsp"
end
?>
