<?lsp

-- (*1)
-- The JavaScript code we use requires that we pipe the data via the
-- FuguHub server to disable the cross browser prevention logic
-- in the browser.

-- We can now access any server by using the URI:
-- /Config-Wizard/protected/_r_/domainname/path

-- The redirector object is created in the session object and is
-- therefore automatically removed when the session expires.

local session = request:session(true)
if not session.redirector then
   session.redirector = ba.create.redirector("protected/_r_")
   app.dir:insert(session.redirector)
end


-- If not set by parent LSP page.
if not gateways then
   gateways,ipAddresses = app.getPrivGw()
end

if #ipAddresses > 0 then
   ipAddress = ipAddresses[1]
else
   ipAddress=app.getPrivateIp()
end

?>
<script>
var wanAddr;
var pfConsole=null; // Port Forward Console
function setPfConsole(text)
{
   if( !pfConsole )
      pfConsole = document.getElementById("pfConsole");
   pfConsole.innerHTML = text;
};

function printTestResult(httpOk, httpsOk)
{
   var msg;
   var exmsg="";
   var failedMsg = ". You may have made an error when you configured Port Forwarding or you ISP may be blocking the Web-Server ports. We suggest that you call your ISP and verify if they block any ports.</p>"
   var intro = "<p><b>Test results:</b></p>";
   if(httpOk == "OK" && httpsOk == "OK")
   {
      msg="<p>Congratulations. Our online server FuguHub.com has verified, by connecting to your WAN address "+
         wanAddr+
         ", that regular HTTP and secure HTTP (HTTPS) are working. Your Port Forwarding is properly configured.</p><p>Click the arrow to continue.</p>";
   }
   else if(httpOk != "OK" && httpsOk != "OK")
   {
      msg="<p>Our online server FuguHub.com was unable to connect to your FuguHub server via your router";
      exmsg = failedMsg;
   }
   else
   {
      msg="We successfully connected to your server using " +
         (httpOk == "OK" ? "HTTP" : "HTTPS") +
         " but not using "+
         (httpsOk == "OK" ? "HTTP" : "HTTPS");
      exmsg = failedMsg;
   }
   setPfConsole(intro+msg+exmsg);
}


function testPF()
{
   setPfConsole("<p><b>Running test...<br/>Please wait.</b></p>")
   var rpc = new HttpAsynchRpc();
   var r={
      onResponse:function(respData, status, e) {
         if(status == 200) {
            var httpOk = respData.getResponseHeader("http");
            var httpsOk = respData.getResponseHeader("https");
            printTestResult(httpOk, httpsOk)
         }
         else {
            setPfConsole("<p>Test failed: status="+status+"</p>")
         }
      }
   };
   rpc.asynchSend(r, "GET", "_r_/FuguHub.com/bd/testserver.lsp")

}

function showWan(myip)
{
   wanAddr=myip;
   var elem = document.getElementById("wanaddr");
   elem.innerHTML = myip + ", and your WAN URL is: http://"+myip;
   var elem = document.getElementById("defWanMsg");
   elem.parentNode.removeChild(elem);
   var elem = document.getElementById("WanMsg");
   elem.style.visibility="visible"; 
};


//Code for dynamically adding the WAN IP address to the document.
onload = function()
{
try {
   var rpc = new HttpAsynchRpc();
   var r={
      onResponse:function(respData, status, e) {
         if(status == 200)
            showWan(respData.getResponseHeader("myip"));
         else
           setPfConsole("<p style='color:red;font-weight:bold'>Warning: The server is unable to connect to the Internet. This could indicate a problem with your network settings such as the default gateway settings or DNS settings.</p>");
      }
   };
   rpc.asynchSend(r, "GET", "_r_/FuguHub.com/bd/myip.lsp")
} catch(e) {}
};
</script>

<h1>Manual Port Mapping Instructions</h1>

<p>The web-site portforward.com is specifically designed to help you
configure Port Forwarding. This site contains step by step guidelines
for how to set up Port Forwarding for FuguHub. Portforward.com
tells you to set up a static IP address for your computer, but in most
cases this is generally not needed as new routers should remember your
PC's MAC address (Ethernet Address). Just make sure that you do not turn off your
router. Also, some routers allow you to lock in the IP address by
using your PC's MAC address -- this is referred to as static DHCP.  If
the terminology is unclear, you can read about this at
portforward.com.</p>

<p><b>Instructions:</b></p>
<ol>
<li><p>Read <a href="http://www.portforward.com/help/portforwarding.htm" target="blank">What is Port Forwarding</a> if you do not understand this terminology.</p></li>
<li><p>Login to your router.
<?lsp if #gateways>0 then ?>
Your router might be accessible via one of the following IP adrresses:
</p>
<ul>
<?lsp
for i,v in ipairs(gateways) do
   response:write("<li><a href='http://",v,"' target='_blank'>http://",v,"</a></li>")
end
?>
</ul>
<p>You may not have a router that allows remote configuration if none of the links work.
<?lsp else print "<p>" end ?>
The router will most likely ask you to authenticate. Try the <a href="RouterPasswd.txt" target="blank">router's default password</a> if you do not know your password.</p>
</li>

<li><p>Follow the portforward.com step by step guidelines for how to <a href="http://www.portforward.com/english/applications/port_forwarding/FuguHub/FuguHubindex.htm" target="_blank">configure Port Forwarding for your router</a>.
<ul>
<li><b>Notice:</b> portforward.com tries to sell you a tool for automating the port forwarding. You will find a small "skip ad" button in the top right corner. Click this link. You can purchase the non UPnP based software configuration tool from portforward.com if you are unable to configure port forwarding manually or you can try the free <a href="http://www.simpleportforwarding.com/download" target="_blank>">Simple Port Forwarding</a> tool, which is similar to portforward.com's tool.</li>
<li>Scroll down on portforward.com until you find your router.</li>
<li>Click the link that matches your router and follow the tutorial.</li>
</ul>
<?lsp if ipAddress then ?>
<p>We have detected that you should use the following data for your Port Forwarding:</p>
<table border="1" cellpadding="5">
<tr><th>HTTP type</th><th>Protocol type</th><th>External port</th><th>Private IP</th><th>Private Port</th></tr>
<tr><td>HTTP</td><td>TCP</td><td>80</td><td><?lsp=ipAddress?></td><td><?lsp=bd.port?></td></tr>
<tr><td>Secure HTTP</td><td>TCP</td><td>443</td><td><?lsp=ipAddress?></td><td><?lsp=bd.sslport?></td></tr>
</table>
<p><br/></p>
<?lsp end ?>
</li>

<li>
<p id="defWanMsg">Ask a friend to test your web-server when you have configured your router. Tell him to enter your WAN IP address in his browser as http://69.123.225.54, where 69.123.225.54 is an example of a WAN address. You can get your WAN IP address <a href="http://www.whatismyip.com/" target="_blank">here</a>. Your friend should see your FuguHub start page if you managed to correctly configure your router.</p>

<div id="WanMsg" style="visibility:hidden">
<p>Your WAN IP address is: <span id="wanaddr"></span>. Our online server FuguHub.com can automatically test if you have properly configured port forwarding by connecting to your WAN URL. Click the button below when you have completed the Port Forwarding configuration.</p>

<h1>Test your configuration</h1>
<br/>
<p style="text-align:center">
<a style="background:#F6F4F8 url(/rtl/images/btn-purple.gif) repeat-x left bottom;padding:10px;border:solid 1px" href="javascript:testPF();" class="button">Test Port Forward Configuration</a>
<br/></p>
</div>
<div id="pfConsole" style="height:10em"></div>
</li>

</ol>
