<?lsp

local tinsert=table.insert
local fmt=string.format
local list2tab = bd.list2tab
local tab2list = bd.tab2list

-- Collect all url encoded data.
local data={}
do
   for key,val in request:datapairs() do
      val = val:gsub("^%s*(.-)%s*$", "%1") -- trim
      if #val ~= 0 and not val:find'[<>]' then
         data[key]=val
      end
   end
end


local function sendredirect(key,val)
   local url=request:url()
   if key then
      response:sendredirect(fmt("%s?%s=%s",url, key, val and ba.urlencode(val) or ""))
   else
      response:sendredirect(url)
   end
end

local function sendredirect2role()
   if data.role then
      sendredirect("role", data.role)
   else
      sendredirect()
   end
end

local function emitOptions(list, selname)
   table.sort(list)
   for _,v in ipairs(list) do
      response:write('<option ',selname == v and 'selected="selected" ' or '',
                     'value="',ba.urlencode(v),'">',v,'</option>')
   end
end

local rdb=bd.db.roles.load()
local roles=list2tab(rdb.v)
local newrole = data.role and not roles[data.role]
local rolesinfo=rdb.i
local roleinfo
if data.role then
   roleinfo = rolesinfo[data.role]
end

if request:method() == "POST" then
   if data.role then
      if data.save then
         bd.db.roles.add(data.role, data.info, true)
      elseif data.remove then
         bd.db.roles.remove(data.role)
         sendredirect()
         return
      end
   end
   sendredirect2role()
   return
end

 
headerdata=[[
<link href="style.css" rel="stylesheet" type="text/css" />
<style>
.talignr {text-align:right;}
select,textarea {width:160px;margin:3px}
fieldset { float:left;}
table, tr, td {margin:0;padding:0}
td { vertical-align: top; }
.hiddenc {display:none}
#advancedaccess, #basicaccess { width:150px; }
</style>
<script type="text/javascript">
var IE = /*@cc_on!@*/false;
$(function() {
   $("#gotorole").remove();
   $("#role").mouseup(function() {
      setTimeout(function() {
         window.location = window.location.pathname+"?role="+escape($("#role option:selected").text())
      }, 100);
   });
});
</script>
]]
 
title="Menu: Administrator Panel: Manage Roles"
response:include".header.lsp"

?>

<div id="panel">
<?lsp emitHelpBut("roles") ?>
<p><b><?lsp
 response:write(fmt("%s Role Name: %s", newrole and 'New' or '',
                    data.role and data.role or ''))
?></b></p>


<form method="POST">
<table><tr>
<td>
<fieldset>
  <legend><b> All Roles </b></legend>
  <select id="role" name="role" size="30">
    <?lsp emitOptions(rdb.v, data.role) ?>
  </select>
  <br/>
   <input type="submit" name="remove" value="Delete Role" />
   <input id="gotorole" type="submit" name="gotorole" value="Goto Role" />
</fieldset>
</td>
<td>
<table>
  <tr><td>
    <fieldset>
      <legend><b> Role Information </b></legend>
      <textarea name="info" style="width:400px" rows="8"><?lsp=roleinfo and roleinfo or ""?></textarea>
    </fieldset>
  </td></tr>
  <tr><td>
   <?lsp= data.role and '<input type="submit" name="save" value="Save"/>' or ''?>
  </td></tr>
  <tr><td>
    <?lsp if newrole then ?>
       <p>The new role is not saved before you press the "Save" button.</p>
    <?lsp else ?>
    <fieldset style="margin-top:40px">
      <legend><b> Create New Role </b></legend>
      <b>Role Name:</b>&nbsp;<input type="text" name="role" value=""/>
      <br/>
      <input type="submit" name="gotorole" value="Create"/>
    </fieldset>
    <?lsp end ?>
  </td></tr>
</table>
</td>
</tr>
</table>
</form>
</div>

<?lsp response:include".footer.lsp" ?>
